.. :changelog:

*******
History
*******

0.1.1 2014-02-14
================
* Bug fixes

  * fix initializing the extension without an app
  * don't rate limit static files 


0.1.0 2014-02-13
================
* first release.

